### Mafia schedule package

This is package to generate and work with schedules of mafia tournaments

Author: [Dmitry Bimatov](mailto:dbimatov@gmail.com)

Code in [Github repository](https://github.com/dimtom/MafSchedule)

